@@ -10,15 +10,17 @@ from trytond.pool import Pool
 from trytond.config import config
 from trytond.transaction import Transaction
 
+from trytond.modules.company.tests import CompanyTestMixin
 from trytond.modules.notification_email import notification \
     as notification_module
 
 FROM = 'tryton@example.com'
 
 
-class NotificationEmailTestCase(ModuleTestCase):
+class NotificationEmailTestCase(CompanyTestMixin, ModuleTestCase):
     "Test Notification Email module"
     module = 'notification_email'
+    extras = ['company', 'commission', 'party', 'web_user']
 
     def setUp(self):
         super(NotificationEmailTestCase, self).setUp()
@@ -107,8 +109,7 @@ class NotificationEmailTestCase(ModuleTestCase):
                 datamanager=ANY)
             _, _, msg = sendmail.call_args[0]
             self.assertEqual(msg['From'], FROM)
-            self.assertEqual(
-                msg['Subject'], 'Notification Email-Michael Scott')
+            self.assertEqual(msg['Subject'], 'Notification Email')
             self.assertEqual(msg['To'], 'Administrator <user@example.com>')
             self.assertEqual(msg['Auto-Submitted'], 'auto-generated')
             self.assertEqual(msg.get_content_type(), 'multipart/alternative')
@@ -155,8 +156,7 @@ class NotificationEmailTestCase(ModuleTestCase):
             user, FROM, ['Administrator <user@example.com>'], [], [], [en])
 
         self.assertEqual(msg['From'], FROM)
-        self.assertEqual(
-            msg['Subject'], 'Notification Email-Michael Scott')
+        self.assertEqual(msg['Subject'], 'Notification Email')
         self.assertEqual(msg['To'], 'Administrator <user@example.com>')
         self.assertEqual(msg.get_content_type(), 'multipart/mixed')
         self.assertEqual(
